<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Филтър:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Избиране шрифт на терминала</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Предварителен преглед</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Bookmarks</source>
        <translation>Отметки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Натиснете &quot;%1&quot;, за да видите терминала.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Следващ Раздел</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Предишен Раздел</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Left</source>
        <translation>Преместване на раздела &amp;наляво</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>Move Tab &amp;Right</source>
        <translation>Преместете раздела на&amp;дясно</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Разделяне на терминала &amp;Хоризонтално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Разделяне на терминала &amp;Вертикално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Свиване на подтерминал</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Изчистване на активния терминал</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <source>Keep window open when it loses focus</source>
        <translation>Задържане на прозореца отворен, когато загуби фокус</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Предишен раздел в историята</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Следващ раздел в историята</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Tab</source>
        <translation>Раздел</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Go to</source>
        <translation>Отиване до</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Горен Подтерминал</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Долен подтерминал</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Ляв подтерминал</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;Десен подтерминал</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Copy &amp;Selection</source>
        <translation>Копиране на &amp;селекцията</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste Clip&amp;board</source>
        <translation>Поставяне на клипборда</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Paste S&amp;election</source>
        <translation>Поставяне на &amp;селекцията</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;in</source>
        <translation>&amp;Увеличаване</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom &amp;out</source>
        <translation>Намаляване</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Zoom rese&amp;t</source>
        <translation>Нулиране на мащаба</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>&amp;Find...</source>
        <translation>&amp;Намиране...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Handle history...</source>
        <translation>Обработване на историята...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>&amp;Save Session</source>
        <translation>&amp; Запазване на сесията</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>&amp;Load Session</source>
        <translation>&amp; Зареждане на сесията</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Превключване на менюто</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Rename session</source>
        <translation>Преименуване на сесията</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Нов Раздел</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Нов раздел от предварително зададени</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;Терминал</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="368"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;Хоризонтални терминали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;Вертикални терминали</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 Терминал&amp;а</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Затваряне на раздела</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Window</source>
        <translation>&amp;Нов прозорец</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Предпочитания...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>&amp;Quit</source>
        <translation>&amp;Излизане</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Скриване на рамката на прозорците</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Показване на лентата с раздели</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Toggle Bookmarks</source>
        <translation>Превключване на отметки</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Отдолу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>&amp;Top</source>
        <translation>&amp;Отгоре</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Right</source>
        <translation>&amp;Отдясно</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>&amp;Left</source>
        <translation>&amp;Отляво</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Заглавна лента на раздели</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;None</source>
        <translation>&amp;Без лента</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Позиция на лентата на превъртане</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Блок</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Долна черта</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Вертикална черта</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Форма на курсора</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Exit QTerminal</source>
        <translation>Излизане от QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Do not ask again</source>
        <translation>Не питай отново</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Are you sure you want to exit?</source>
        <translation>Наистина ли искате да излезете?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>About</source>
        <translation>Относно</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Лек и мощен мултиплатформен терминален емулатор</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>Copyright (C) </source>
        <translation>Авторски права (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>LXQt Project</source>
        <translation>Проектът LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Development: </source>
        <translation>Разработка: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Настройки на терминала</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Външен вид</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Клавишни комбинации</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Падащи менюта</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Отметки</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Скриване на лентата с раздели само с едно кликване</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Цветова схема</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Позиция на лентата за превъртане</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Брой и позиция на терминалите:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Показване граница на текущия терминал</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Прозрачност на терминала</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Прозрачност на приложението</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>един терминал</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 хоризонтални терминала</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 вертикални терминала</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 терминала</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Смяна...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Позиция на разделите</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Стил на интерфейса</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Показване на лентата с менюта</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Форма на курсора</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Промяна на заглавието на прозореца въз основа на текущия терминал</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Промяна на иконата на прозореца въз основа на текущия терминал</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Активиране на двупосочна поддръжка на текст</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Фоново изображение:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Избиране</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Показване на размера на терминала при преоразмеряване</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Фиксирана ширина на раздела:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Показване на бутона за затваряне на всеки раздел</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Отстояние на текста от рамката</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Използване на съдържащи се в шрифта символи,чертаещи полета</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Символите за избиране на елементи от менюто (акцелератори) се активират с Alt и могат да доведат до смущения в терминала.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Деактивиране акцелератори на менюто</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="830"/>
        <source>Emulation</source>
        <translation>Емулатор</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Действие след поставяне</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="654"/>
        <source>Confirm multiline paste</source>
        <translation>Потвърждаване на многоредово копиране</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="661"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Премахване на завършващите символи за нов ред в копиран текст</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new terminals in current working directory</source>
        <translation>Отваряне на нов терминал в текущата работна директория</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="692"/>
        <source>Save Size when closing</source>
        <translation>Запазване на размера при затваряне</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="685"/>
        <source>Save Position when closing</source>
        <translation>Запазване на позиция при затваряне</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="678"/>
        <source>Ask for confirmation when closing</source>
        <translation>Питане за потвърждение при затваряне</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Неограничена история</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Размер на историята (в редове)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="781"/>
        <source>Default $TERM</source>
        <translation>$TERM по подразбиране</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="704"/>
        <source>Start with this size:</source>
        <translation>Стартиране с размер:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Режим на заден план:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Никой</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Разтегляне</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Мащабиране</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Събиране</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Центриране</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Определя, дали псевдографичните символи трябва да се изчертават от QTerminal вътрешно или да се оставят на основните библиотеки за изобразяване на шрифтове.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Превключва използването на задебелен шрифт за изобразяване на интензивни цветове</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Използване на получерен шрифт за изобразяване на интензивни цветове</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Скриване на рамката на прозорците</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="839"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Кое поведение да се емулира. Имайте предвид, че това не трябва непременно да съответства на вашата операционна система.&lt;/p&gt;&lt;p&gt;Ако не сте сигурни използвайте &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; емулация.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="817"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Командата трябва да има формат: име на програмата и аргумент, съдържащ местоположението на файла с историята</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="820"/>
        <source>Handle history command</source>
        <translation>Команда за обработване на историята</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <location filename="../forms/propertiesdialog.ui" line="725"/>
        <source> px</source>
        <translation> пиксела</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="732"/>
        <source>Get current size</source>
        <translation>Вземане на текущия размер</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="767"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Отваряне на нов раздел отдясно на активния раздел</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Ако опцията не избрана, новите раздели ще бъдат отваряни най-вдясно</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Close tab on middle-click</source>
        <translation>Затваряне на раздела със средния бутон на мишката</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="647"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Принудително изключване на режима на поставяне със скоби</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Word selection characters</source>
        <translation>Символи за избор на думи</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation>Когато избирате текст по думи, считайте тези знаци за част от думите в допълнение към буквено-цифровите знаци</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>:@-./_~</source>
        <translation>:@-./_~</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Режимът на поставяне със скоби е полезен за поставяне на многоредови низове.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="774"/>
        <source>Audible bell</source>
        <translation>Звуково уведомяване</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="863"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>За да редактирате клавишна комбинация:
1. Щракнете двукратно върху отговарящото поле в колоната Комбинация
2. Натиснете желаната комбинация и я освободете
3. Кликнете върху съответното поле Действие или натиснете Enter

За да премахнете / деактивирате пряк път, в точка 2 натиснете само модификатор (като Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Shortcut</source>
        <translation>Действие</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Key</source>
        <translation>Комбинация</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Show on start</source>
        <translation>Показване при стартиране</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="917"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Бутонът за заключване е показан на хоризонталната лента с раздели</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="920"/>
        <source>Keep window open when it loses focus</source>
        <translation>Задържане на прозореца отворен, когато загуби фокус</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="927"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Height</source>
        <translation>Височина</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <location filename="../forms/propertiesdialog.ui" line="965"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>Width</source>
        <translation>Широчина</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="979"/>
        <source>Shortcut:</source>
        <translation>Клавишна комбинация:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1046"/>
        <source>Edit bookmark file contents</source>
        <translation>Редактиране на съдържанието на файла с отметки</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1005"/>
        <source>Enable bookmarks</source>
        <translation>Активиране на отметки</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1014"/>
        <source>Bookmark file</source>
        <translation>Файл с отметки</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1027"/>
        <source>Find...</source>
        <translation>Търсене...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1036"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Можете да зададете собствено местоположение на файла с отметки. То позволява лесно споделяне на отметки с инструменти като OwnCloud или Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Без лента</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Отляво</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Отдясно</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Отгоре</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>Отдолу</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Блок</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Долна черта</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>Вертикална черта</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Без преместване</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Превъртане нагоре</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Превъртане надолу</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="271"/>
        <source>Examples</source>
        <translation>Примери</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="422"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Изображения (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="512"/>
        <source>Open bookmarks file</source>
        <translation>Отваряне на файла с отметките</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>XML files (*.xml)</source>
        <translation>XML файлове (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="515"/>
        <source>All files (*)</source>
        <translation>Всички файлове (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="614"/>
        <location filename="../propertiesdialog.cpp" line="618"/>
        <source>Question</source>
        <translation>Запитване</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="614"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Искате ли да презапишете този файл с отметки?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="618"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Името на файла с отметки не завършва с &apos;.xml&apos;.
Сигурни ли сте, че искате да го презапишете?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="626"/>
        <source>Warning</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="626"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Не могат да бъдат записани отметки в този файл:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="206"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Системни настройки по подразбиране</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Choose a background image</source>
        <translation>Изберете фоново изображение</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Синхронизирани отметки</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="81"/>
        <location filename="../tabwidget.cpp" line="235"/>
        <source>Shell No. %1</source>
        <translation>Терминал: %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>Tab name</source>
        <translation>Име на раздела</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="204"/>
        <source>New tab name:</source>
        <translation>Име на нов раздел:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="224"/>
        <source>Select new tab title color</source>
        <translation>Изберете нов цвят на заглавието на раздела</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="253"/>
        <source>Close session</source>
        <translation>Затваряне на сесията</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="255"/>
        <source>Change title color</source>
        <translation>Промяна на цвета на заглавието</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>Зареждане на сесия</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>Списък на запазените сесии:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Основен прозорец</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Действия</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощ</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Изглед</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Редактиране</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Относно...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Относно &amp;Qt..</translation>
    </message>
</context>
</TS>
